pub fn compute_fetch_challenges<R: RngCore + CryptoRng>(
rng: &mut R,
store: &ServerMessageStore,
total_responses: usize,
) -> Vec<FetchResponse>Expand description
Given a set of ciphertext bundles (C, X, Z) and their associated uuid, compute a fixed-length set of “challenges” >= the number of SeverMessageStore entries. A challenge is returned as a tuple of DH agreement outputs (or random data tuples of the same length). For benchmarking purposes, supply the rng as a separable parameter, and allow the total number of expected responses to be specified as a paremeter (worst case performance when the number of items in the server store approaches num total_responses.)